"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var tongwen_core_1 = require("tongwen-core");
var immer_1 = __importDefault(require("immer"));
var lodash_1 = require("lodash");
var dictionary_1 = require("./resources/dictionary");
function createSimplifiedToTraditionalConverter() {
    var NO_TRANSLATION_PROVIDED_FROM_TRADITIONAL_TO_SIMPLIFIED = [];
    var src = {
        s2t: [dictionary_1.CHAR_DICTIONARY, dictionary_1.PHRASE_DICTIONARY],
        t2s: NO_TRANSLATION_PROVIDED_FROM_TRADITIONAL_TO_SIMPLIFIED
    };
    var converter = tongwen_core_1.createConverterMap(src);
    return {
        convert: function (text) {
            return converter.phrase("s2t" /* s2t */, text);
        },
        convertMetaData: function (metadata) {
            return lodash_1.mapValues(metadata, this.convert);
        },
        convertChapters: function (chapters) {
            var _this = this;
            return lodash_1.mapValues(chapters, function (chapter) {
                return immer_1.default(chapter, function (draft) {
                    draft.text = _this.convert(draft.text);
                });
            });
        },
        convertBook: function (book) {
            var metadata = this.convertMetaData(book.metadata);
            var chapters = this.convertChapters(book.chapters);
            return { metadata: metadata, chapters: chapters };
        },
        converter: converter
    };
}
exports.createSimplifiedToTraditionalConverter = createSimplifiedToTraditionalConverter;
